@@ -2,7 +2,7 @@ package Net::GitHub;
 
 use Any::Moose;
 
-our $VERSION = '0.40_04';
+our $VERSION = '0.43_01';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 sub new {
@@ -11,6 +11,7 @@ sub new {
 
     my $obj;
     if ( exists $params->{version} and $params->{version} == 2 ) {
+        warn "Github will terminate API v1 and API v2 in 1 month on May 1st, 2012\n";
         require Net::GitHub::V2;
         return Net::GitHub::V2->new($params);
     } else {
@@ -35,19 +36,28 @@ Net::GitHub - Perl Interface for github.com
 
     use Net::GitHub;
 
-    my $github = Net::GitHub->new( login => 'fayland', pass => 'secret' ); # default to Net::GitHub::V3
+    # default to v3
+    my $github = Net::GitHub->new(  # Net::GitHub::V3
+        login => 'fayland', pass => 'secret'
+    );
 
-    # for backwards
-    my $github = Net::GitHub->new(  # Net::GitHub::V2
+    # suggested
+    # use OAuth to create token with user/pass
+    my $github = Net::GitHub->new(  # Net::GitHub::V3
+        access_token => $token
+    );
+
+    # for backwards, NOTE: Github will terminate API v1 and API v2 in 1 month on May 1st, 2012
+    my $github = Net::GitHub->new(
         version => 2,
         owner => 'fayland', name => 'perl-net-github'
     );
-    
+
     # for V3
     # L<Net::GitHub::V3::Users>
     my $user = $github->user->show('nothingmuch');
     $github->user->update( bio => 'Just Another Perl Programmer' );
-    
+
     # L<Net::GitHub::V3::Repos>
     my @repos = $github->repos->list;
     my $rp = $github->repos->create( {
@@ -68,6 +78,28 @@ Read L<Net::GitHub::V3> for API usage.
 
 If you prefer object oriented way, L<Pithub> is 'There is more than one way to do it'.
 
+=head2 FAQ
+
+=over 4
+
+=item * create access_token for Non-Web Application
+
+    my $gh = Net::GitHub::V3->new( login => 'fayland', pass => 'secret' );
+    my $oauth = $gh->oauth;
+    my $o = $oauth->create_authorization( {
+        scopes => ['user', 'public_repo', 'repo', 'gist'], # just ['public_repo']
+        note   => 'test purpose',
+    } );
+    print $o->{token};
+
+after create the token, you can use it without your password publicly written
+
+    my $github = Net::GitHub->new(
+        access_token => $token, # from above
+    );
+
+=back
+
 =head1 Git
 
 L<http://github.com/fayland/perl-net-github/>
@@ -84,7 +116,7 @@ Everyone who is listed in B<Changes>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2011 Fayland Lam all rights reserved.
+Copyright 2009-2012 Fayland Lam all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
