@@ -11,6 +11,11 @@ use Net::GitHub::V3::Users;
 use Net::GitHub::V3::Repos;
 use Net::GitHub::V3::Issues;
 use Net::GitHub::V3::PullRequests;
+use Net::GitHub::V3::Orgs;
+use Net::GitHub::V3::GitData;
+use Net::GitHub::V3::Gists;
+use Net::GitHub::V3::OAuth;
+use Net::GitHub::V3::Events;
 
 has '+is_main_module' => (default => 1);
 
@@ -24,6 +29,26 @@ has 'user' => (
     },
 );
 
+has 'org' => (
+    is => 'rw',
+    isa => 'Net::GitHub::V3::Orgs',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Orgs->new( $self->args_to_pass );
+    },
+);
+
+has 'gist' => (
+    is => 'rw',
+    isa => 'Net::GitHub::V3::Gists',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Gists->new( $self->args_to_pass );
+    },
+);
+
 has 'repos' => (
     is => 'rw',
     isa => 'Net::GitHub::V3::Repos',
@@ -57,6 +82,37 @@ has 'pull_request' => (
     },
 );
 
+has 'git_data' => (
+    is => 'rw',
+    isa => 'Net::GitHub::V3::GitData',
+    lazy => 1,
+    predicate => 'is_git_data_init',
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::GitData->new( $self->args_to_pass );
+    },
+);
+
+has 'oauth' => (
+    is => 'rw',
+    isa => 'Net::GitHub::V3::OAuth',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::OAuth->new( $self->args_to_pass );
+    },
+);
+
+has 'event' => (
+    is => 'rw',
+    isa => 'Net::GitHub::V3::Events',
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Events->new( $self->args_to_pass );
+    },
+);
+
 no Any::Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -72,7 +128,7 @@ Net::GitHub::V3 - Github API v3
 Prefer:
 
     use Net::GitHub;
-    my $github = Net::GitHub->new(
+    my $gh = Net::GitHub->new(
         version => 3,
         login => 'fayland', pass => 'mypass',
         # or
@@ -82,7 +138,7 @@ Prefer:
 Or:
 
     use Net::GitHub::V3;
-    my $github = Net::GitHub::V3->new(
+    my $gh = Net::GitHub::V3->new(
         login => 'fayland', pass => 'mypass',
         # or
         # access_token => $oauth_token
@@ -103,7 +159,7 @@ There are two ways to authenticate through GitHub API v3:
 =item login/pass
 
     my $gh = Net::GitHub::V3->new( login => $ENV{GITHUB_USER}, pass => $ENV{GITHUB_PASS} );
-    
+
 =item access_token
 
     my $gh = Net::GitHub->new( access_token => $ENV{GITHUB_ACCESS_TOKEN} );
@@ -125,7 +181,7 @@ return raw L<HTTP::Response> object
         # login/pass or access_token
         raw_string => 1
     );
-    
+
 return L<HTTP::Response> response content as string
 
 =head3 api_throttle
@@ -159,7 +215,7 @@ query API directly
     $gh->set_default_user_repo('fayland', 'perl-net-github'); # take effects for all $gh->
     $gh->repos->set_default_user_repo('fayland', 'perl-net-github'); # take effects on $gh->repos
 
-<B>To ease the keyboard, we provied two ways to call any method which starts with :user/:repo</B>
+B<To ease the keyboard, we provied two ways to call any method which starts with :user/:repo>
 
 1. SET user/repos before call methods below
 
@@ -203,6 +259,28 @@ L<Net::GitHub::V3::Issues>
 
 L<Net::GitHub::V3::PullRequests>
 
+=head3 org
+
+    my @orgs   = $gh->org->orgs;
+
+L<Net::GitHub::V3::Orgs>
+
+=head3 git_data
+
+L<Net::GitHub::V3::GitData>
+
+=head3 gist
+
+L<Net::GitHub::V3::Gists>
+
+=head3 oauth
+
+L<Net::GitHub::V3::OAuth>
+
+=head3 event
+
+L<Net::GitHub::V3::Events>
+
 =head1 SEE ALSO
 
 L<Any::Moose>, L<Pithub>
